@@ -13,7 +13,7 @@
 """Client for accessing IBM Quantum runtime service."""
 
 import logging
-from typing import Any, Dict, List, Optional
+from typing import Any
 from datetime import datetime as python_datetime
 from requests import Response
 
@@ -44,24 +44,24 @@ class RuntimeClient(BaseBackendClient):
             **params.connection_parameters(),
         )
         self._api = Runtime(self._session)
-        self._configuration_registry: Dict[str, Dict[str, Any]] = {}
+        self._configuration_registry: dict[str, dict[str, Any]] = {}
         self._instance = params.instance
 
     def program_run(
         self,
         program_id: str,
-        backend_name: Optional[str],
-        params: Dict,
-        image: Optional[str],
-        log_level: Optional[str],
-        session_id: Optional[str],
-        job_tags: Optional[List[str]] = None,
-        max_execution_time: Optional[int] = None,
-        start_session: Optional[bool] = False,
-        session_time: Optional[int] = None,
-        private: Optional[bool] = False,
-        calibration_id: Optional[str] = None,
-    ) -> Dict:
+        backend_name: str | None,
+        params: dict,
+        image: str | None,
+        log_level: str | None,
+        session_id: str | None,
+        job_tags: list[str] | None = None,
+        max_execution_time: int | None = None,
+        start_session: bool | None = False,
+        session_time: int | None = None,
+        private: bool | None = False,
+        calibration_id: str | None = None,
+    ) -> dict:
         """Run the specified program.
 
         Args:
@@ -96,7 +96,7 @@ class RuntimeClient(BaseBackendClient):
             calibration_id=calibration_id,
         )
 
-    def job_get(self, job_id: str, exclude_params: bool = True) -> Dict:
+    def job_get(self, job_id: str, exclude_params: bool = True) -> dict:
         """Get job data.
 
         Args:
@@ -116,12 +116,12 @@ class RuntimeClient(BaseBackendClient):
         backend_name: str = None,
         pending: bool = None,
         program_id: str = None,
-        job_tags: Optional[List[str]] = None,
-        session_id: Optional[str] = None,
-        created_after: Optional[python_datetime] = None,
-        created_before: Optional[python_datetime] = None,
+        job_tags: list[str] | None = None,
+        session_id: str | None = None,
+        created_after: python_datetime | None = None,
+        created_before: python_datetime | None = None,
         descending: bool = True,
-    ) -> Dict:
+    ) -> dict:
         """Get job data for all jobs.
 
         Args:
@@ -196,7 +196,7 @@ class RuntimeClient(BaseBackendClient):
         """
         return self._api.program_job(job_id).logs()
 
-    def job_metadata(self, job_id: str) -> Dict[str, Any]:
+    def job_metadata(self, job_id: str) -> dict[str, Any]:
         """Get job metadata.
 
         Args:
@@ -209,11 +209,11 @@ class RuntimeClient(BaseBackendClient):
 
     def create_session(
         self,
-        backend: Optional[str] = None,
-        instance: Optional[str] = None,
-        max_time: Optional[int] = None,
-        mode: Optional[str] = None,
-    ) -> Dict[str, Any]:
+        backend: str | None = None,
+        instance: str | None = None,
+        max_time: int | None = None,
+        mode: str | None = None,
+    ) -> dict[str, Any]:
         """Create a session.
 
         Args:
@@ -233,7 +233,7 @@ class RuntimeClient(BaseBackendClient):
         """Update session so jobs can no longer be submitted."""
         self._api.runtime_session(session_id=session_id).close()
 
-    def session_details(self, session_id: str) -> Dict[str, Any]:
+    def session_details(self, session_id: str) -> dict[str, Any]:
         """Get session details.
 
         Args:
@@ -244,7 +244,7 @@ class RuntimeClient(BaseBackendClient):
         """
         return self._api.runtime_session(session_id=session_id).details()
 
-    def list_backends(self) -> List[Dict[str, Any]]:
+    def list_backends(self) -> list[dict[str, Any]]:
         """Return IBM backends available for this service instance.
 
         Returns:
@@ -254,8 +254,8 @@ class RuntimeClient(BaseBackendClient):
         return self._api.backends()["devices"]
 
     def backend_configuration(
-        self, backend_name: str, refresh: bool = False, calibration_id: Optional[str] = None
-    ) -> Dict[str, Any]:
+        self, backend_name: str, refresh: bool = False, calibration_id: str | None = None
+    ) -> dict[str, Any]:
         """Return the configuration of the IBM backend.
 
         Args:
@@ -275,7 +275,7 @@ class RuntimeClient(BaseBackendClient):
             ).configuration()
         return self._configuration_registry[backend_name].copy()
 
-    def backend_status(self, backend_name: str) -> Dict[str, Any]:
+    def backend_status(self, backend_name: str) -> dict[str, Any]:
         """Return the status of the IBM backend.
 
         Args:
@@ -289,9 +289,9 @@ class RuntimeClient(BaseBackendClient):
     def backend_properties(
         self,
         backend_name: str,
-        datetime: Optional[python_datetime] = None,
-        calibration_id: Optional[str] = None,
-    ) -> Dict[str, Any]:
+        datetime: python_datetime | None = None,
+        calibration_id: str | None = None,
+    ) -> dict[str, Any]:
         """Return the properties of the IBM backend.
 
         Args:
@@ -321,7 +321,7 @@ class RuntimeClient(BaseBackendClient):
         """
         return self._api.program_job(job_id).update_tags(tags)
 
-    def cloud_usage(self) -> Dict[str, Any]:
+    def cloud_usage(self) -> dict[str, Any]:
         """Return cloud instance usage information.
 
         Returns:
