@@ -12,7 +12,7 @@
 
 """IBM Cloud Backend REST adapter."""
 
-from typing import Dict, Any, Optional
+from typing import Any
 from datetime import datetime as python_datetime
 
 from qiskit_ibm_runtime.api.rest.base import RestAdapterBase
@@ -39,7 +39,7 @@ class CloudBackend(RestAdapterBase):
         self.backend_name = backend_name
         super().__init__(session, "{}/backends/{}".format(url_prefix, backend_name))
 
-    def configuration(self, calibration_id: Optional[str] = None) -> Dict[str, Any]:
+    def configuration(self, calibration_id: str | None = None) -> dict[str, Any]:
         """Return backend configuration.
 
         Args:
@@ -56,8 +56,8 @@ class CloudBackend(RestAdapterBase):
         return self.session.get(url, params=params, headers=self._HEADER_JSON_ACCEPT).json()
 
     def properties(
-        self, datetime: Optional[python_datetime] = None, calibration_id: Optional[str] = None
-    ) -> Dict[str, Any]:
+        self, datetime: python_datetime | None = None, calibration_id: str | None = None
+    ) -> dict[str, Any]:
         """Return backend properties.
 
         Returns:
@@ -77,7 +77,7 @@ class CloudBackend(RestAdapterBase):
             response["backend_name"] = self.backend_name
         return response
 
-    def status(self) -> Dict[str, Any]:
+    def status(self) -> dict[str, Any]:
         """Return backend status.
 
         Returns:
