@@ -76,7 +76,7 @@ class DoubleSliceSpan(ExecutionSpan):
         mask.reshape(np.prod(shape[:-1], dtype=int), shape[-1])[(args_sl, shots_sl)] = True
         return mask
 
-    def filter_by_pub(self, pub_idx: int | Iterable[int]) -> "DoubleSliceSpan":
+    def filter_by_pub(self, pub_idx: int | Iterable[int]) -> DoubleSliceSpan:
         pub_idx = {pub_idx} if isinstance(pub_idx, int) else set(pub_idx)
         slices = {idx: val for idx, val in self._data_slices.items() if idx in pub_idx}
         return DoubleSliceSpan(self.start, self.stop, slices)
