@@ -125,7 +125,7 @@ class ExecutionSpan(abc.ABC):
         return not pub_idx.isdisjoint(self.pub_idxs)
 
     @abc.abstractmethod
-    def filter_by_pub(self, pub_idx: int | Iterable[int]) -> "ExecutionSpan":
+    def filter_by_pub(self, pub_idx: int | Iterable[int]) -> ExecutionSpan:
         """Return a new span whose slices are filtered to the provided pub indices.
 
         For example, if this span contains slice information for pubs with indices 1, 3, 4 and
