@@ -32,7 +32,7 @@ class FakeAlmadenV2(fake_backend.FakeBackendV2):
         15 ↔ 16 ↔ 17 ↔ 18 ↔ 19
     """
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_almaden.json"  # type: ignore
-    props_filename = "props_almaden.json"  # type: ignore
-    backend_name = "fake_almaden"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_almaden.json"
+    props_filename = "props_almaden.json"
+    backend_name = "fake_almaden"
