@@ -26,7 +26,7 @@ class FakeArmonkV2(fake_backend.FakeBackendV2):
         0
     """
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_armonk.json"  # type: ignore
-    props_filename = "props_armonk.json"  # type: ignore
-    backend_name = "fake_armonk"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_armonk.json"
+    props_filename = "props_armonk.json"
+    backend_name = "fake_armonk"
