@@ -22,7 +22,7 @@ from qiskit_ibm_runtime.fake_provider import fake_backend
 class FakeAuckland(fake_backend.FakeBackendV2):
     """A fake 27 qubit backend."""
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_auckland.json"  # type: ignore
-    props_filename = "props_auckland.json"  # type: ignore
-    backend_name = "fake_auckland"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_auckland.json"
+    props_filename = "props_auckland.json"
+    backend_name = "fake_auckland"
