@@ -32,7 +32,7 @@ class FakeBoeblingenV2(fake_backend.FakeBackendV2):
         15 ↔ 16 ↔ 17 ↔ 18 ↔ 19
     """
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_boeblingen.json"  # type: ignore
-    props_filename = "props_boeblingen.json"  # type: ignore
-    backend_name = "fake_boeblingen"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_boeblingen.json"
+    props_filename = "props_boeblingen.json"
+    backend_name = "fake_boeblingen"
