@@ -21,7 +21,7 @@ from qiskit_ibm_runtime.fake_provider import fake_backend
 class FakeBrooklynV2(fake_backend.FakeBackendV2):
     """A fake Brooklyn V2 backend."""
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_brooklyn.json"  # type: ignore
-    props_filename = "props_brooklyn.json"  # type: ignore
-    backend_name = "fake_brooklyn"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_brooklyn.json"
+    props_filename = "props_brooklyn.json"
+    backend_name = "fake_brooklyn"
