@@ -21,7 +21,7 @@ from qiskit_ibm_runtime.fake_provider import fake_backend
 class FakeCasablancaV2(fake_backend.FakeBackendV2):
     """A fake 7 qubit backend."""
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_casablanca.json"  # type: ignore
-    props_filename = "props_casablanca.json"  # type: ignore
-    backend_name = "fake_casablanca"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_casablanca.json"
+    props_filename = "props_casablanca.json"
+    backend_name = "fake_casablanca"
