@@ -30,7 +30,7 @@ class FakeEssexV2(fake_backend.FakeBackendV2):
             4
     """
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_essex.json"  # type: ignore
-    props_filename = "props_essex.json"  # type: ignore
-    backend_name = "fake_essex"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_essex.json"
+    props_filename = "props_essex.json"
+    backend_name = "fake_essex"
