@@ -21,7 +21,7 @@ from qiskit_ibm_runtime.fake_provider import fake_backend
 class FakeFez(fake_backend.FakeBackendV2):
     """A fake 156 qubit backend."""
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_fez.json"  # type: ignore
-    props_filename = "props_fez.json"  # type: ignore
-    backend_name = "fake_fez"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_fez.json"
+    props_filename = "props_fez.json"
+    backend_name = "fake_fez"
