@@ -22,7 +22,7 @@ from qiskit_ibm_runtime.fake_provider import fake_backend
 class FakeGuadalupeV2(fake_backend.FakeBackendV2):
     """A fake 16 qubit backend."""
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_guadalupe.json"  # type: ignore
-    props_filename = "props_guadalupe.json"  # type: ignore
-    backend_name = "fake_guadalupe"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_guadalupe.json"
+    props_filename = "props_guadalupe.json"
+    backend_name = "fake_guadalupe"
