@@ -21,7 +21,7 @@ from qiskit_ibm_runtime.fake_provider import fake_backend
 class FakeJakartaV2(fake_backend.FakeBackendV2):
     """A fake 7 qubit V2 backend."""
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_jakarta.json"  # type: ignore
-    props_filename = "props_jakarta.json"  # type: ignore
-    backend_name = "fake_jakarta"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_jakarta.json"
+    props_filename = "props_jakarta.json"
+    backend_name = "fake_jakarta"
