@@ -21,7 +21,7 @@ from qiskit_ibm_runtime.fake_provider import fake_backend
 class FakeManhattanV2(fake_backend.FakeBackendV2):
     """A fake Manhattan backend."""
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_manhattan.json"  # type: ignore
-    props_filename = "props_manhattan.json"  # type: ignore
-    backend_name = "fake_manhattan"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_manhattan.json"
+    props_filename = "props_manhattan.json"
+    backend_name = "fake_manhattan"
