@@ -21,7 +21,7 @@ from qiskit_ibm_runtime.fake_provider import fake_backend
 class FakeManilaV2(fake_backend.FakeBackendV2):
     """A fake 5 qubit backend."""
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_manila.json"  # type: ignore
-    props_filename = "props_manila.json"  # type: ignore
-    backend_name = "fake_manila"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_manila.json"
+    props_filename = "props_manila.json"
+    backend_name = "fake_manila"
