@@ -21,7 +21,7 @@ from qiskit_ibm_runtime.fake_provider import fake_backend
 class FakeNairobiV2(fake_backend.FakeBackendV2):
     """A fake 7 qubit backend."""
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_nairobi.json"  # type: ignore
-    props_filename = "props_nairobi.json"  # type: ignore
-    backend_name = "fake_nairobi"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_nairobi.json"
+    props_filename = "props_nairobi.json"
+    backend_name = "fake_nairobi"
