@@ -22,7 +22,7 @@ from qiskit_ibm_runtime.fake_provider import fake_backend
 class FakeOslo(fake_backend.FakeBackendV2):
     """A fake 7 qubit backend."""
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_oslo.json"  # type: ignore
-    props_filename = "props_oslo.json"  # type: ignore
-    backend_name = "fake_oslo"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_oslo.json"
+    props_filename = "props_oslo.json"
+    backend_name = "fake_oslo"
