@@ -22,7 +22,7 @@ from qiskit_ibm_runtime.fake_provider import fake_backend
 class FakePoughkeepsieV2(fake_backend.FakeBackendV2):
     """A fake Poughkeepsie backend."""
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_poughkeepsie.json"  # type: ignore
-    props_filename = "props_poughkeepsie.json"  # type: ignore
-    backend_name = "fake_poughkeepsie"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_poughkeepsie.json"
+    props_filename = "props_poughkeepsie.json"
+    backend_name = "fake_poughkeepsie"
