@@ -22,7 +22,7 @@ from qiskit_ibm_runtime.fake_provider import fake_backend
 class FakePrague(fake_backend.FakeBackendV2):
     """A fake 33 qubit backend."""
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_prague.json"  # type: ignore
-    props_filename = "props_prague.json"  # type: ignore
-    backend_name = "fake_prague"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_prague.json"
+    props_filename = "props_prague.json"
+    backend_name = "fake_prague"
