@@ -21,7 +21,7 @@ from qiskit_ibm_runtime.fake_provider import fake_backend
 class FakeRochesterV2(fake_backend.FakeBackendV2):
     """A fake Rochester backend."""
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_rochester.json"  # type: ignore
-    props_filename = "props_rochester.json"  # type: ignore
-    backend_name = "fake_rochester"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_rochester.json"
+    props_filename = "props_rochester.json"
+    backend_name = "fake_rochester"
