@@ -21,7 +21,7 @@ from qiskit_ibm_runtime.fake_provider import fake_backend
 class FakeSantiagoV2(fake_backend.FakeBackendV2):
     """A fake Santiago backend."""
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_santiago.json"  # type: ignore
-    props_filename = "props_santiago.json"  # type: ignore
-    backend_name = "fake_santiago"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_santiago.json"
+    props_filename = "props_santiago.json"
+    backend_name = "fake_santiago"
