@@ -21,7 +21,7 @@ from qiskit_ibm_runtime.fake_provider import fake_backend
 class FakeValenciaV2(fake_backend.FakeBackendV2):
     """A fake 5 qubit backend."""
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_valencia.json"  # type: ignore
-    props_filename = "props_valencia.json"  # type: ignore
-    backend_name = "fake_valencia"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_valencia.json"
+    props_filename = "props_valencia.json"
+    backend_name = "fake_valencia"
