@@ -28,7 +28,7 @@ class FakeVigoV2(fake_backend.FakeBackendV2):
             2
     """
 
-    dirname = os.path.dirname(__file__)  # type: ignore
-    conf_filename = "conf_vigo.json"  # type: ignore
-    props_filename = "props_vigo.json"  # type: ignore
-    backend_name = "fake_vigo"  # type: ignore
+    dirname = os.path.dirname(__file__)
+    conf_filename = "conf_vigo.json"
+    props_filename = "props_vigo.json"
+    backend_name = "fake_vigo"
