@@ -13,7 +13,7 @@
 """Module for interfacing with an IBM Quantum Backend."""
 
 import logging
-from typing import Optional, Any, List, Union
+from typing import Any
 from datetime import datetime as python_datetime
 from copy import deepcopy
 from packaging.version import Version
@@ -155,8 +155,8 @@ class IBMBackend(Backend):
         configuration: QasmBackendConfiguration,
         service: "qiskit_runtime_service.QiskitRuntimeService",
         api_client: RuntimeClient,
-        instance: Optional[str] = None,
-        calibration_id: Optional[str] = None,
+        instance: str | None = None,
+        calibration_id: str | None = None,
     ) -> None:
         """IBMBackend constructor.
 
@@ -249,7 +249,7 @@ class IBMBackend(Backend):
         )
 
     @property
-    def calibration_id(self) -> Union[str, None]:
+    def calibration_id(self) -> str | None:
         """The calibration id used for this backend."""
         return self._calibration_id
 
@@ -281,7 +281,7 @@ class IBMBackend(Backend):
         return None
 
     @property
-    def meas_map(self) -> List[List[int]]:
+    def meas_map(self) -> list[list[int]]:
         """Return the grouping of measurements which are multiplexed
 
         This is required to be implemented if the backend supports Pulse
@@ -303,7 +303,7 @@ class IBMBackend(Backend):
         self._convert_to_target()
         return self._target
 
-    def target_history(self, datetime: Optional[python_datetime] = None) -> Target:
+    def target_history(self, datetime: python_datetime | None = None) -> Target:
         """A :class:`qiskit.transpiler.Target` object for the backend.
 
         Returns:
@@ -329,8 +329,8 @@ class IBMBackend(Backend):
         self._convert_to_target(refresh=True)
 
     def properties(
-        self, refresh: bool = False, datetime: Optional[python_datetime] = None
-    ) -> Optional[BackendProperties]:
+        self, refresh: bool = False, datetime: python_datetime | None = None
+    ) -> BackendProperties | None:
         """Return the backend properties, subject to optional filtering.
 
         This data describes qubits properties (such as T1 and T2),
@@ -517,7 +517,7 @@ class IBMRetiredBackend(IBMBackend):
         self,
         configuration: QasmBackendConfiguration,
         service: "qiskit_runtime_service.QiskitRuntimeService",
-        api_client: Optional[RuntimeClient] = None,
+        api_client: RuntimeClient | None = None,
     ) -> None:
         """IBMRetiredBackend constructor.
 
@@ -540,7 +540,7 @@ class IBMRetiredBackend(IBMBackend):
         """Default runtime options."""
         return Options(shots=4000)
 
-    def properties(self, refresh: bool = False, datetime: Optional[python_datetime] = None) -> None:
+    def properties(self, refresh: bool = False, datetime: python_datetime | None = None) -> None:
         """Return the backend properties."""
         return None
 
@@ -552,13 +552,13 @@ class IBMRetiredBackend(IBMBackend):
     def from_name(
         cls,
         backend_name: str,
-        api: Optional[RuntimeClient] = None,
+        api: RuntimeClient | None = None,
     ) -> "IBMRetiredBackend":
         """Return a retired backend from its name."""
         configuration = QasmBackendConfiguration(
             backend_name=backend_name,
             backend_version="0.0.0",
-            online_date="2019-10-16T04:00:00Z",
+            online_date="2019-10-16T04:00:00Z",  # type: ignore[arg-type]
             n_qubits=1,
             basis_gates=[],
             simulator=False,
@@ -569,4 +569,4 @@ class IBMRetiredBackend(IBMBackend):
             gates=[GateConfig(name="TODO", parameters=[], qasm_def="TODO")],
             coupling_map=[[0, 1]],
         )
-        return cls(configuration, api)
+        return cls(configuration, api)  # type: ignore[arg-type]
