@@ -12,7 +12,6 @@
 
 """Padding pass to insert Delay into empty timeslots for dynamic circuit backends."""
 
-from typing import Optional
 import warnings
 
 from qiskit.circuit import Qubit
@@ -61,7 +60,7 @@ class PadDelay(BlockBasePadder):
         durations: InstructionDurations = None,
         fill_very_end: bool = True,
         schedule_idle_qubits: bool = False,
-        block_ordering_callable: Optional[BlockOrderingCallableType] = None,
+        block_ordering_callable: BlockOrderingCallableType | None = None,
         target: Target = None,
     ):
         """Create new padding delay pass.
