@@ -13,7 +13,8 @@
 """Utility functions for scheduling passes."""
 
 import warnings
-from typing import Callable, Generator, Optional, Tuple, Union
+from typing import TypeAlias
+from collections.abc import Callable, Generator
 from functools import lru_cache
 
 from qiskit.circuit import ControlFlowOp, Measure, Reset, Parameter
@@ -47,8 +48,8 @@ def block_order_op_nodes(dag: DAGCircuit) -> Generator[DAGOpNode, None, None]:
     @lru_cache(maxsize=8192)
     def _emit(
         node: DAGOpNode,
-        grouped_measure: Tuple[DAGOpNode],
-        block_triggers: Tuple[DAGOpNode],
+        grouped_measure: tuple[DAGOpNode],
+        block_triggers: tuple[DAGOpNode],
     ) -> bool:
         """Should we emit this node?"""
         for measure in grouped_measure:
@@ -130,11 +131,9 @@ def block_order_op_nodes(dag: DAGCircuit) -> Generator[DAGOpNode, None, None]:
     _emit.cache_clear()
 
 
-InstrKey = Union[
-    Tuple[str, None, None],
-    Tuple[str, Tuple[int], None],
-    Tuple[str, Tuple[int], Tuple[Parameter]],
-]
+InstrKey: TypeAlias = (
+    tuple[str, None, None] | tuple[str, tuple[int], None] | tuple[str, tuple[int], tuple[Parameter]]
+)
 
 
 class DynamicCircuitInstructionDurations(InstructionDurations):
@@ -151,7 +150,7 @@ class DynamicCircuitInstructionDurations(InstructionDurations):
 
     def __init__(
         self,
-        instruction_durations: Optional[InstructionDurationsType] = None,
+        instruction_durations: InstructionDurationsType | None = None,
         dt: float = None,
         enable_patching: bool = True,
     ):
@@ -202,7 +201,7 @@ class DynamicCircuitInstructionDurations(InstructionDurations):
         return cls(instruction_durations, dt=dt)
 
     def update(
-        self, inst_durations: Optional[InstructionDurationsType], dt: float = None
+        self, inst_durations: InstructionDurationsType | None, dt: float = None
     ) -> "DynamicCircuitInstructionDurations":
         """Update self with inst_durations (inst_durations overwrite self). Overrides the default
         durations for certain hardcoded instructions.
@@ -292,7 +291,7 @@ class DynamicCircuitInstructionDurations(InstructionDurations):
             # Fall back to reset key if measure not available
             self._convert_and_patch_key(key)
 
-    def _get_duration(self, key: InstrKey) -> Tuple[int, str]:
+    def _get_duration(self, key: InstrKey) -> tuple[int, str]:
         """Handling for the complicated structure of this class.
 
         TODO: This class implementation should be simplified in Qiskit. Too many edge cases.
